@@ -164,7 +164,7 @@ class Aurflux(discord.Client):
         asyncio.create_task(self.router.submit(AurfluxEvent(self, f":{event}", *args, **kwargs)))
 
     def register_cog(self, cog: ty.Type[AurfluxCog]):
-        cog(self)
+        self.cogs.append(cog(self))
 
     async def startup(self, token, *args, **kwargs):
         await self.start(token, *args, **kwargs)
